==> zio-aws-omics_2.12-5.20.22.1-sources.jar: zio/aws/omics/model/ImportReferenceJobItem.scala <==
package zio.aws.omics.model
import zio.aws.omics.model.primitives.{
  RoleArn,
  ReferenceStoreId,
  ImportJobId,
  SyntheticTimestamp_date_time
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class ImportReferenceJobItem(
    completionTime: Optional[SyntheticTimestamp_date_time] = Optional.Absent,
    creationTime: SyntheticTimestamp_date_time,
    id: ImportJobId,
    referenceStoreId: ReferenceStoreId,
    roleArn: RoleArn,
    status: zio.aws.omics.model.ReferenceImportJobStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.omics.model.ImportReferenceJobItem = {
    import ImportReferenceJobItem.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
      .builder()
      .optionallyWith(
        completionTime.map(value =>
          SyntheticTimestamp_date_time.unwrap(value): Instant
        )
      )(_.completionTime)
      .creationTime(SyntheticTimestamp_date_time.unwrap(creationTime): Instant)
      .id(ImportJobId.unwrap(id): java.lang.String)
      .referenceStoreId(
        ReferenceStoreId.unwrap(referenceStoreId): java.lang.String
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .status(status.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.omics.model.ImportReferenceJobItem.ReadOnly =
    zio.aws.omics.model.ImportReferenceJobItem.wrap(buildAwsValue())
}
object ImportReferenceJobItem {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.omics.model.ImportReferenceJobItem =
      zio.aws.omics.model.ImportReferenceJobItem(
        completionTime.map(value => value),
        creationTime,
        id,
        referenceStoreId,
        roleArn,
        status
      )
    def completionTime: Optional[SyntheticTimestamp_date_time]
    def creationTime: SyntheticTimestamp_date_time
    def id: ImportJobId
    def referenceStoreId: ReferenceStoreId
    def roleArn: RoleArn
    def status: zio.aws.omics.model.ReferenceImportJobStatus
    def getCompletionTime: ZIO[Any, AwsError, SyntheticTimestamp_date_time] =
      AwsError.unwrapOptionField("completionTime", completionTime)
    def getCreationTime: ZIO[Any, Nothing, SyntheticTimestamp_date_time] =
      ZIO.succeed(creationTime)
    def getId: ZIO[Any, Nothing, ImportJobId] = ZIO.succeed(id)
    def getReferenceStoreId: ZIO[Any, Nothing, ReferenceStoreId] =
      ZIO.succeed(referenceStoreId)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.omics.model.ReferenceImportJobStatus] =
      ZIO.succeed(status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
  ) extends zio.aws.omics.model.ImportReferenceJobItem.ReadOnly {
    override val completionTime: Optional[SyntheticTimestamp_date_time] =
      zio.aws.core.internal
        .optionalFromNullable(impl.completionTime())
        .map(value =>
          zio.aws.omics.model.primitives.SyntheticTimestamp_date_time(value)
        )
    override val creationTime: SyntheticTimestamp_date_time =
      zio.aws.omics.model.primitives
        .SyntheticTimestamp_date_time(impl.creationTime())
    override val id: ImportJobId =
      zio.aws.omics.model.primitives.ImportJobId(impl.id())
    override val referenceStoreId: ReferenceStoreId =
      zio.aws.omics.model.primitives.ReferenceStoreId(impl.referenceStoreId())
    override val roleArn: RoleArn =
      zio.aws.omics.model.primitives.RoleArn(impl.roleArn())
    override val status: zio.aws.omics.model.ReferenceImportJobStatus =
      zio.aws.omics.model.ReferenceImportJobStatus.wrap(impl.status())
  }
  def wrap(
      impl: software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
  ): zio.aws.omics.model.ImportReferenceJobItem.ReadOnly = new Wrapper(impl)
}

==> zio-aws-omics_2.12-6.20.74.1-sources.jar: zio/aws/omics/model/ImportReferenceJobItem.scala <==
package zio.aws.omics.model
import zio.aws.omics.model.primitives.{
  SyntheticTimestamp_date_time,
  RoleArn,
  ReferenceStoreId,
  ImportJobId
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class ImportReferenceJobItem(
    id: ImportJobId,
    referenceStoreId: ReferenceStoreId,
    roleArn: RoleArn,
    status: zio.aws.omics.model.ReferenceImportJobStatus,
    creationTime: SyntheticTimestamp_date_time,
    completionTime: Optional[SyntheticTimestamp_date_time] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.omics.model.ImportReferenceJobItem = {
    import ImportReferenceJobItem.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
      .builder()
      .id(ImportJobId.unwrap(id): java.lang.String)
      .referenceStoreId(
        ReferenceStoreId.unwrap(referenceStoreId): java.lang.String
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .status(status.unwrap)
      .creationTime(SyntheticTimestamp_date_time.unwrap(creationTime): Instant)
      .optionallyWith(
        completionTime.map(value =>
          SyntheticTimestamp_date_time.unwrap(value): Instant
        )
      )(_.completionTime)
      .build()
  }
  def asReadOnly: zio.aws.omics.model.ImportReferenceJobItem.ReadOnly =
    zio.aws.omics.model.ImportReferenceJobItem.wrap(buildAwsValue())
}
object ImportReferenceJobItem {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.omics.model.ImportReferenceJobItem =
      zio.aws.omics.model.ImportReferenceJobItem(
        id,
        referenceStoreId,
        roleArn,
        status,
        creationTime,
        completionTime.map(value => value)
      )
    def id: ImportJobId
    def referenceStoreId: ReferenceStoreId
    def roleArn: RoleArn
    def status: zio.aws.omics.model.ReferenceImportJobStatus
    def creationTime: SyntheticTimestamp_date_time
    def completionTime: Optional[SyntheticTimestamp_date_time]
    def getId: ZIO[Any, Nothing, ImportJobId] = ZIO.succeed(id)
    def getReferenceStoreId: ZIO[Any, Nothing, ReferenceStoreId] =
      ZIO.succeed(referenceStoreId)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.omics.model.ReferenceImportJobStatus] =
      ZIO.succeed(status)
    def getCreationTime: ZIO[Any, Nothing, SyntheticTimestamp_date_time] =
      ZIO.succeed(creationTime)
    def getCompletionTime: ZIO[Any, AwsError, SyntheticTimestamp_date_time] =
      AwsError.unwrapOptionField("completionTime", completionTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
  ) extends zio.aws.omics.model.ImportReferenceJobItem.ReadOnly {
    override val id: ImportJobId =
      zio.aws.omics.model.primitives.ImportJobId(impl.id())
    override val referenceStoreId: ReferenceStoreId =
      zio.aws.omics.model.primitives.ReferenceStoreId(impl.referenceStoreId())
    override val roleArn: RoleArn =
      zio.aws.omics.model.primitives.RoleArn(impl.roleArn())
    override val status: zio.aws.omics.model.ReferenceImportJobStatus =
      zio.aws.omics.model.ReferenceImportJobStatus.wrap(impl.status())
    override val creationTime: SyntheticTimestamp_date_time =
      zio.aws.omics.model.primitives
        .SyntheticTimestamp_date_time(impl.creationTime())
    override val completionTime: Optional[SyntheticTimestamp_date_time] =
      zio.aws.core.internal
        .optionalFromNullable(impl.completionTime())
        .map(value =>
          zio.aws.omics.model.primitives.SyntheticTimestamp_date_time(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.omics.model.ImportReferenceJobItem
  ): zio.aws.omics.model.ImportReferenceJobItem.ReadOnly = new Wrapper(impl)
}
